@@ -1,15 +1,12 @@
+"""Check Python ASTs against templates"""
 import ast
-import sys
-PY3 = sys.version_info[0] >= 3
 
-__version__ = '0.2.3'
+__version__ = '0.3.0'
 
-if PY3:
-    def mkarg(name):
-        return ast.arg(arg=name)
-else:
-    def mkarg(name):
-        return ast.Name(id=name, ctx=ast.Param())
+def mkarg(name):
+    # This was defined for Python 2-3 compatibility, and now left in place to
+    # avoid breaking code that uses it.
+    return ast.arg(arg=name)
 
 def must_exist(node, path):
     """Checker function for an item or list that must exist
@@ -37,7 +34,7 @@ def must_not_exist(node, path):
     raise ASTMismatch(path, node, "nothing")
 
 class name_or_attr(object):
-    """Make a checker function for :class:`ast.Name` or :class:`ast.Attribute`.
+    """Checker for :class:`ast.Name` or :class:`ast.Attribute`
     
     These are often used in similar ways - depending on how you do imports,
     objects will be referenced as names or as attributes of a module. By using
@@ -62,6 +59,46 @@ class name_or_attr(object):
         else:
             raise ASTNodeTypeMismatch(path, node, "Name or Attribute")
 
+class single_assign:
+    """Checker for :class:`ast.Assign` or :class:`ast.AnnAssign`
+
+    :class:`~ast.Assign` is a plain assignment. This will match only assignments
+    to a single target (``a = 1`` but not ``a = b = 1``).
+    :class:`~ast.AnnAssign` is an annotated assignment, like ``a: int = 7``.
+    *target* and *value* may be AST nodes to check, so this would match any
+    assignment to ``a``::
+
+        astcheck.single_assign(target=ast.Name(id='a'))
+
+    Annotated assignments don't necessarily have a value: ``a: int`` is parsed
+    as an :class:`~ast.AnnAssign` node. Use :func:`must_exist` to avoid matching
+    these::
+
+        astcheck.single_assign(target=ast.Name(id='a'), value=astcheck.must_exist)
+    """
+    def __init__(self, target=None, value=None):
+        self.target = target
+        self.value = value
+
+    def __repr__(self):
+        return "astcheck.single_assign(%r, %r)" % (self.target, self.value)
+
+    def __call__(self, node, path):
+        if isinstance(node, ast.Assign):
+            if len(node.targets) != 1:
+                raise ASTNodeListMismatch(path+['targets'], node.targets, [self.target])
+            if self.target is not None:
+                assert_ast_like(node.targets[0], self.target, path + ['targets', 0])
+            if self.value is not None:
+                assert_ast_like(node.value, self.value, path + ['value'])
+        elif hasattr(ast, 'AnnAssign') and isinstance(node, ast.AnnAssign):
+            if self.target is not None:
+                assert_ast_like(node.target, self.target, path + ['target'])
+            if self.value is not None:
+                assert_ast_like(node.value, self.value, path + ['value'])
+        else:
+            raise ASTNodeTypeMismatch(path, node, "Assign or AnnAssign")
+
 class listmiddle(object):
     def __init__(self, front=None, back=None):
         super(listmiddle, self).__init__()
@@ -203,4 +240,4 @@ def is_ast_like(sample, template):
         assert_ast_like(sample, template)
         return True
     except ASTMismatch:
-        return False
\ No newline at end of file
+        return False
